@@ -32,7 +32,7 @@ FLAGS:
     -z, --zero-terminated         Line delimiter is NUL (\0), not LF (\n)
     -h, --help                    Print this help and exit
     -m, --complement              Invert fields (e.g. '2' becomes '1,3:')
-    -j, --(no-)join               Print selected parts with delimiter inbetween
+    -j, --(no-)join               Print selected parts with delimiter in between
 
 OPTIONS:
     -f, --fields <bounds>         Fields to keep, 1-indexed, comma separated.
@@ -86,7 +86,7 @@ fn parse_args() -> Result<Opt, pico_args::Error> {
     let mut pargs = pico_args::Arguments::from_env();
 
     if pargs.contains(["-h", "--help"]) {
-        print!("{}", HELP);
+        print!("{HELP}");
         std::process::exit(0);
     }
 
@@ -131,17 +131,11 @@ fn parse_args() -> Result<Opt, pico_args::Error> {
         if let Ok(Some(regex_text)) = pargs.opt_value_from_str::<_, String>(["-e", "--regex"]) {
             Some(RegexBag {
                 normal: Regex::new(&regex_text).unwrap_or_else(|e| {
-                    eprintln!(
-                        "tuc: runtime error. The regular expression is malformed. {}",
-                        e
-                    );
+                    eprintln!("tuc: runtime error. The regular expression is malformed. {e}");
                     std::process::exit(1);
                 }),
                 greedy: Regex::new(&format!("({})+", &regex_text)).unwrap_or_else(|e| {
-                    eprintln!(
-                        "tuc: runtime error. The regular expression is malformed. {}",
-                        e
-                    );
+                    eprintln!("tuc: runtime error. The regular expression is malformed. {e}");
                     std::process::exit(1);
                 }),
             })
@@ -186,7 +180,7 @@ fn parse_args() -> Result<Opt, pico_args::Error> {
     }
 
     if !remaining.is_empty() {
-        eprintln!("tuc: unexpected arguments {:?}", remaining);
+        eprintln!("tuc: unexpected arguments {remaining:?}");
         eprintln!("Try 'tuc --help' for more information.");
         std::process::exit(1);
     }
